==> suggest_a_feature-0.2.0.tar.gz: lib/src/presentation/l10n/suggestions_localizations_en.dart <==
import 'package:suggest_a_feature/src/presentation/l10n/suggestions_localizations.dart';

// ignore_for_file: lines_longer_than_80_chars

/// The translations for English (`en`).
class SuggestionsLocalizationsEn extends SuggestionsLocalizations {
  SuggestionsLocalizationsEn([super.locale = 'en']);

  @override
  String get suggestion => 'Suggestion';

  @override
  String get suggestAFeature => 'Suggest a feature';

  @override
  String get feature => 'Feature';

  @override
  String get bug => 'Bug';

  @override
  String get postedBy => 'Posted by:';

  @override
  String get upvote => 'Upvote';

  @override
  String get attachedPhotos => 'Attached photos';

  @override
  String get labels => 'Labels';

  @override
  String get notifyMe => 'Notify me';

  @override
  String get notificationDescription => 'When this suggestion is completed';

  @override
  String get save => 'Save';

  @override
  String get edit => 'Edit suggestion';

  @override
  String get delete => 'Delete suggestion';

  @override
  String get deletionQuestion => 'Are you sure you want to delete the suggestion?';

  @override
  String get deletionPhotoQuestion => 'Are you sure you want to delete this photo?';

  @override
  String get title => 'Briefly describe your suggestion';

  @override
  String get description => 'Describe your suggestion in details';

  @override
  String get postAnonymously => 'Post anonymously';

  @override
  String get postFromAdmin => 'Post from Admin';

  @override
  String get suggest => 'Suggest';

  @override
  String get status => 'Status';

  @override
  String get anonymousAuthorName => 'Anonymous';

  @override
  String get adminAuthorName => 'Admin';

  @override
  String get requests => 'Requests';

  @override
  String get requestsHeader => 'Feature requests';

  @override
  String get requestsDescription => 'Join other users';

  @override
  String get inProgress => 'In Progress';

  @override
  String get inProgressHeader => 'Features in development';

  @override
  String get inProgressDescription => 'What will be added to the app soon';

  @override
  String get completed => 'Completed';

  @override
  String get completedHeader => 'Implemented features';

  @override
  String get completedDescription => 'What’s been already implemented';

  @override
  String get duplicated => 'Duplicated';

  @override
  String get duplicatedHeader => 'Duplicated features';

  @override
  String get duplicatedDescription => 'What’s been already suggested';

  @override
  String get declined => 'Declined';

  @override
  String get cancelledHeader => 'Cancelled features';

  @override
  String get cancelledDescription => 'What’s been cancelled';

  @override
  String get savingImageError => 'Error: can’t save the photo';

  @override
  String get savingImageSuccess => 'The photo has been successfully saved';

  @override
  String get addPhoto => 'Add Photo';

  @override
  String get cancel => 'Cancel';

  @override
  String get done => 'Done';

  @override
  String get yesDelete => 'Yes, delete';

  @override
  String get commentsTitle => 'Comments';

  @override
  String get newComment => 'New сomment';

  @override
  String get commentHint => 'Your comment…';

  @override
  String get publish => 'Publish';

  @override
  String get add => 'Add';

  @override
  String get eventPhotosRestriction => 'You can attach up to 10 photos 🖼️';
}

==> suggest_a_feature-0.3.0.tar.gz: lib/src/presentation/l10n/suggestions_localizations_en.dart <==
import 'package:suggest_a_feature/src/presentation/l10n/suggestions_localizations.dart';

// ignore_for_file: lines_longer_than_80_chars

/// The translations for English (`en`).
class SuggestionsLocalizationsEn extends SuggestionsLocalizations {
  SuggestionsLocalizationsEn([super.locale = 'en']);

  @override
  String get suggestion => 'Suggestion';

  @override
  String get suggestAFeature => 'Suggest a feature';

  @override
  String get feature => 'Feature';

  @override
  String get bug => 'Bug';

  @override
  String get postedBy => 'Posted by:';

  @override
  String get upvote => 'Upvote';

  @override
  String get attachedPhotos => 'Attached photos';

  @override
  String get labels => 'Labels';

  @override
  String get notifyMe => 'Notify me';

  @override
  String get notificationDescription => 'When this suggestion is completed';

  @override
  String get save => 'Save';

  @override
  String get edit => 'Edit suggestion';

  @override
  String get delete => 'Delete suggestion';

  @override
  String get deletionQuestion =>
      'Are you sure you want to delete the suggestion?';

  @override
  String get deletionPhotoQuestion =>
      'Are you sure you want to delete this photo?';

  @override
  String get title => 'Briefly describe your suggestion';

  @override
  String get description => 'Describe your suggestion in details';

  @override
  String get postAnonymously => 'Post anonymously';

  @override
  String get postFromAdmin => 'Post from Admin';

  @override
  String get suggest => 'Suggest';

  @override
  String get status => 'Status';

  @override
  String get anonymousAuthorName => 'Anonymous';

  @override
  String get adminAuthorName => 'Admin';

  @override
  String get requests => 'Requests';

  @override
  String get requestsHeader => 'Feature requests';

  @override
  String get requestsDescription => 'Join other users';

  @override
  String get inProgress => 'In Progress';

  @override
  String get inProgressHeader => 'Features in development';

  @override
  String get inProgressDescription => 'What will be added to the app soon';

  @override
  String get completed => 'Completed';

  @override
  String get completedHeader => 'Implemented features';

  @override
  String get completedDescription => 'What’s been already implemented';

  @override
  String get duplicated => 'Duplicated';

  @override
  String get duplicatedHeader => 'Duplicated features';

  @override
  String get duplicatedDescription => 'What’s been already suggested';

  @override
  String get declined => 'Declined';

  @override
  String get cancelledHeader => 'Cancelled features';

  @override
  String get cancelledDescription => 'What’s been cancelled';

  @override
  String get savingImageError => 'Error: can’t save the photo';

  @override
  String get savingImageSuccess => 'The photo has been successfully saved';

  @override
  String get addPhoto => 'Add Photo';

  @override
  String get cancel => 'Cancel';

  @override
  String get done => 'Done';

  @override
  String get yesDelete => 'Yes, delete';

  @override
  String get commentsTitle => 'Comments';

  @override
  String get newComment => 'New сomment';

  @override
  String get commentHint => 'Your comment…';

  @override
  String get publish => 'Publish';

  @override
  String get add => 'Add';

  @override
  String get eventPhotosRestriction => 'You can attach up to 10 photos 🖼️';

  @override
  String get sortBy => 'Sort by';

  @override
  String get numberOfLikes => 'Number of likes';

  @override
  String get creationDate => 'Creation date';
}
